﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.IO;
using System.Runtime.Serialization.Json;
using Sprinter.ParcelReg.PartnerPudoService;
using Sprinter.ParcelReg.DocumentService;

namespace Lapker.ParcelRegistrationPUDOClient
{
    class Program
    {
        static void Main(string[] args)
        {
            //True: Parcel registration ony for label printing, and finalize later
            bool onlyLabelPrinting = false;

            #region Prepare the request

            /*
             * https://tsx.lapker.hu/PudoTest/PudoDocumentService?wsdl
             * https://tsx.lapker.hu/PudoTest/PartnerPudoService?wsdl
             * */

            string _prefix = "ASD"; // unique barcode prefix, the customer service gives it to the partners
            string _datum = $"{DateTime.Now.Year}{DateTime.Now.Month}{DateTime.Now.Day}{DateTime.Now.Hour}{DateTime.Now.Minute}{DateTime.Now.Second}";

            List<Parcel> _parcelContainer = new List<Parcel>();

            #region PPP - Normal - Partner hands over the parcel at depot
            Parcel _normal = new Parcel()
            {
                // required field, it decides the service type
                ServiceType = ParcelServiceType.Normal, // Partner hands over the parcel at depot

                // Parcel creation status, we only handle Create
                ParcelCreationStatus = ParcelCreationStatus.Create,

                // Logistics barcode(with the unique prefix). Max 25 chars length
                // It has to be unique and contains only ean128 format characters
                BarCode = $"{_prefix}{_datum}{ParcelServiceType.Normal}",    //Unique generated barcode

                // Accounting barcode, the partner's identifier code for the parcel, it will be shown on the accounting and searchable in the tracking
                // Visible on the label
                // Required field
                AutorizationCode = "AUTH123456",

                #region Parcel price data
                // Collect on delivery price
                PriceAtDelivery = 10000,
                // Collect on delivery currency
                PriceAtDeliveryCurrency = "HUF",    //Have to use this currency code
                // Parcel value, used for compensation
                PackagePrice = 10000,
                // Parcel value currency
                PackagePriceCurrency = "HUF",    //Have to use this currency code
                #endregion

                #region Customer data

                // Customer name
                CustomerName = "Atvevo Jakab",
                // Customer phone number for SMS notification. Have to use this format (Country prefix(+36/0036/06) and only numbers)
                CustomerPhone = "+36701234567",
                // Customer email address
                CustomerEmail = "ugyfel@gmail.com",

                #region Customer address data

                // Customer country code. Optional default HU
                CustomerCountryCode = "HU",

                // Customer postal code
                CustomerPostalCode = "1097",

                // Customer city or settlement
                CustomerCity = "Budapest",

                // Customer street
                CustomerAddress = "Táblás utca",

                // Customer streetnumber and other (floor and door number)
                CustomerStreetNumber = "32. 1/A",

                #endregion

                #endregion

                #region Parcel size data
                //Size category (default small)
                PackageType = PackageType.Small,

                // Parcel weight, max 20kg (in kilograms) (Optional)
                PackageWeight = 5,
                // Parcel Size X dimension (in centimeters) (Optional)
                PackageSizeX = 20,
                // Parcel Size Y dimension (in centimeters) (Optional)
                PackageSizeY = 31,
                // Parcel Size Z dimension (in centimeters) (Optional)
                PackageSizeZ = 10,
                // Parcel Volume (m3) (Optional)
                PackageVolume = 0.006000m,
                #endregion

                //Destination PPP shop code (where the customer takes over the parcel)
                DestinationLocationId = "0000101246"
            };
            _parcelContainer.Add(_normal);
            #endregion

            #region PPP - Pos2Pos - Partner hands over the parcel at PPP, delivered in another PPP
            Parcel _pos2pos = new Parcel()
            {
                // required field, it decides the service type
                ServiceType = ParcelServiceType.Pos2Pos, //Partner hands over the parcel at PPP, delivered in another PPP (Pos2Pos)

                // Parcel creation status, we only handle Create
                ParcelCreationStatus = ParcelCreationStatus.Create,

                // Logistics barcode(with the unique prefix). Max 25 chars length
                // It has to be unique and contains only ean128 format characters
                BarCode = $"{_prefix}{_datum}{ParcelServiceType.Pos2Pos}",    //Unique generated barcode

                // Accounting barcode, the partner's identifier code for the parcel, it will be shown on the accounting and searchable in the tracking
                // Visible on the label
                // Required field
                AutorizationCode = "AUTH123456",

                #region Parcel price data
                // Collect on delivery price
                PriceAtDelivery = 10000,
                // Collect on delivery currency
                PriceAtDeliveryCurrency = "HUF",    //Have to use this currency code
                // Parcel value, used for compensation
                PackagePrice = 10000,
                // Parcel value currency
                PackagePriceCurrency = "HUF",    //Have to use this currency code
                #endregion

                #region Customer data

                // Customer name
                CustomerName = "Atvevo Jakab",
                // Customer phone number for SMS notification. Have to use this format (Country prefix(+36/0036/06) and only numbers)
                CustomerPhone = "+36701234567",
                // Customer email address
                CustomerEmail = "ugyfel@gmail.com",

                #region Customer address data

                // Customer country code. Optional default HU
                CustomerCountryCode = "HU",

                // Customer postal code
                CustomerPostalCode = "1097",

                // Customer city or settlement
                CustomerCity = "Budapest",

                // Customer street
                CustomerAddress = "Táblás utca",

                // Customer streetnumber and other (floor and door number)
                CustomerStreetNumber = "32. 1/A",

                #endregion

                #endregion

                #region Parcel size data
                //Size category (default small)
                PackageType = PackageType.Small,

                // Parcel weight, max 20kg (in kilograms) (Optional)
                PackageWeight = 5,
                // Parcel Size X dimension (in centimeters) (Optional)
                PackageSizeX = 20,
                // Parcel Size Y dimension (in centimeters) (Optional)
                PackageSizeY = 31,
                // Parcel Size Z dimension (in centimeters) (Optional)
                PackageSizeZ = 10,
                // Parcel Volume (m3) (Optional)
                PackageVolume = 0.006000m,
                #endregion

                //Pick up PPP shop code (where the partner hands over the parcel)
                PickupLocationId = "0000101999",
                //Destination PPP shop code (where the customer takes over the parcel)
                DestinationLocationId = "0000101246",

            };
            _parcelContainer.Add(_pos2pos);
            #endregion

            #region PPP - Direct - Partner hands over the parcel at PPP, delivered in the same PPP
            Parcel _direct = new Parcel()
            {
                // required field, it decides the service type
                ServiceType = ParcelServiceType.Direct, //Partner hands over the parcel at PPP, delivered in the same PPP (Direct)

                // Parcel creation status, we only handle Create
                ParcelCreationStatus = ParcelCreationStatus.Create,

                // Logistics barcode(with the unique prefix). Max 25 chars length
                // It has to be unique and contains only ean128 format characters
                BarCode = $"{_prefix}{_datum}{ParcelServiceType.Direct}",    //Unique generated barcode

                // Accounting barcode, the partner's identifier code for the parcel, it will be shown on the accounting and searchable in the tracking
                // Visible on the label
                // Required field
                AutorizationCode = "AUTH123456",

                #region Parcel price data
                // Collect on delivery price
                PriceAtDelivery = 10000,
                // Collect on delivery currency
                PriceAtDeliveryCurrency = "HUF",    //Have to use this currency code
                // Parcel value, used for compensation
                PackagePrice = 10000,
                // Parcel value currency
                PackagePriceCurrency = "HUF",    //Have to use this currency code
                #endregion

                #region Customer data

                // Customer name
                CustomerName = "Atvevo Jakab",
                // Customer phone number for SMS notification. Have to use this format (Country prefix(+36/0036/06) and only numbers)
                CustomerPhone = "+36701234567",
                // Customer email address
                CustomerEmail = "ugyfel@gmail.com",

                #region Customer address data

                // Customer country code. Optional default HU
                CustomerCountryCode = "HU",

                // Customer postal code
                CustomerPostalCode = "1097",

                // Customer city or settlement
                CustomerCity = "Budapest",

                // Customer street
                CustomerAddress = "Táblás utca",

                // Customer streetnumber and other (floor and door number)
                CustomerStreetNumber = "32. 1/A",

                #endregion

                #endregion

                #region Parcel size data
                //Size category (default small)
                PackageType = PackageType.Small,

                // Parcel weight, max 20kg (in kilograms) (Optional)
                PackageWeight = 5,
                // Parcel Size X dimension (in centimeters) (Optional)
                PackageSizeX = 20,
                // Parcel Size Y dimension (in centimeters) (Optional)
                PackageSizeY = 31,
                // Parcel Size Z dimension (in centimeters) (Optional)
                PackageSizeZ = 10,
                // Parcel Volume (m3) (Optional)
                PackageVolume = 0.006000m,
                #endregion

                //Destination PPP shop code (where the customer takes over the parcel)
                DestinationLocationId = "0000101246"
            };
            _parcelContainer.Add(_direct);
            #endregion

            #region PPP - Return - Customer hands over the parcel at PPP, delivered to Partner in Depot
            Parcel _return = new Parcel()
            {
                // required field, it decides the service type
                ServiceType = ParcelServiceType.Return, //Customer hands over the parcel at PPP, delivered to Partner in Depot (Return)

                // Parcel creation status, we only handle Create
                ParcelCreationStatus = ParcelCreationStatus.Create,

                // Logistics barcode(with the unique prefix). Max 25 chars length
                // It has to be unique and contains only ean128 format characters
                BarCode = $"{_prefix}{_datum}{ParcelServiceType.Return}",    //Unique generated barcode

                // Accounting barcode, the partner's identifier code for the parcel, it will be shown on the accounting and searchable in the tracking
                // Visible on the label
                // Required field
                AutorizationCode = "AUTH123456",

                #region Parcel price data
                // Collect on delivery price
                PriceAtDelivery = 10000,
                // Collect on delivery currency
                PriceAtDeliveryCurrency = "HUF",    //Have to use this currency code
                // Parcel value, used for compensation
                PackagePrice = 10000,
                // Parcel value currency
                PackagePriceCurrency = "HUF",    //Have to use this currency code
                #endregion

                #region Customer data

                // Customer name
                CustomerName = "Atvevo Jakab",
                // Customer phone number for SMS notification. Have to use this format (Country prefix(+36/0036/06) and only numbers)
                CustomerPhone = "+36701234567",
                // Customer email address
                CustomerEmail = "ugyfel@gmail.com",

                #region Customer address data

                // Customer country code. Optional default HU
                CustomerCountryCode = "HU",

                // Customer postal code
                CustomerPostalCode = "1097",

                // Customer city or settlement
                CustomerCity = "Budapest",

                // Customer street
                CustomerAddress = "Táblás utca",

                // Customer streetnumber and other (floor and door number)
                CustomerStreetNumber = "32. 1/A",

                #endregion

                #endregion

                #region Parcel size data
                //Size category (default small)
                PackageType = PackageType.Small,

                // Parcel weight, max 20kg (in kilograms) (Optional)
                PackageWeight = 5,
                // Parcel Size X dimension (in centimeters) (Optional)
                PackageSizeX = 20,
                // Parcel Size Y dimension (in centimeters) (Optional)
                PackageSizeY = 31,
                // Parcel Size Z dimension (in centimeters) (Optional)
                PackageSizeZ = 10,
                // Parcel Volume (m3) (Optional)
                PackageVolume = 0.006000m,
                #endregion

                //Pick up PPP shop code (where the customer hands over the parcel). The Destination will be the Partner's default depot
                PickupLocationId = "0000101999",
            };
            _parcelContainer.Add(_return);
            #endregion

            #region Home delivery (HomeDelivery)
            Parcel _homeDelivery = new Parcel()
            {
                // required field, it decides the service type
                ServiceType = ParcelServiceType.HomeDeliver, //Home delivery to the customer

                // Parcel creation status, we only handle Create
                ParcelCreationStatus = ParcelCreationStatus.Create,

                // Logistics barcode(with the unique prefix). Max 25 chars length
                // It has to be unique and contains only ean128 format characters
                BarCode = $"{_prefix}{_datum}HD",    //Unique generated barcode

                // Accounting barcode, the partner's identifier code for the parcel, it will be shown on the accounting and searchable in the tracking
                // Visible on the label
                // Required field
                AutorizationCode = "AUTH123456",

                #region Parcel price data
                // Collect on delivery price
                PriceAtDelivery = 10000,
                // Collect on delivery currency
                PriceAtDeliveryCurrency = "HUF",    //Have to use this currency code
                // Parcel value, used for compensation
                PackagePrice = 10000,

                PackagePriceCurrency = "HUF",    //Have to use this currency code
                #endregion

                #region Customer data

                // Customer name
                CustomerName = "Atvevo Jakab",
                // Customer phone number for SMS notification. Have to use this format (Country prefix(+36/0036/06) and only numbers)
                CustomerPhone = "+36701234567",
                // Customer email address
                CustomerEmail = "ugyfel@gmail.com",

                #region Customer address data

                // Customer country code. Optional default HU
                CustomerCountryCode = "HU",

                // Customer postal code
                CustomerPostalCode = "1097",

                // Customer city or settlement
                CustomerCity = "Budapest",

                // Customer street
                CustomerAddress = "Táblás utca",

                // Customer streetnumber and other (floor and door number)
                CustomerStreetNumber = "32. 1/A",

                #endregion

                #endregion

                #region Parcel size data             
                // Parcel weight (in kilograms) (Optional)
                PackageWeight = 5,
                // Parcel Size X dimension (in centimeters) (Optional)
                PackageSizeX = 20,
                // Parcel Size Y dimension (in centimeters) (Optional)
                PackageSizeY = 31,
                // Parcel Size Z dimension (in centimeters) (Optional)
                PackageSizeZ = 10,
                // Parcel Volume (m3) (Optional)
                PackageVolume = 0.006000m,
                #endregion

                #region csomag adatok

                // Package count delivered together to the same customer
                // CAUTION! The system will generate the given number of package barcode and labels (in format: Barcode, Barcode-2, Barcode-3)
                // The generated barcodes will be in the respone              
                ParcelCount = 1,

                #endregion

                //Transit time type                 //     0 - Before 9 A.M
                TransitTime = 2,                    //     1 - Between 9 and 12 A.M
                                                    //     2 - 1 working day
                                                    //     3 - 2 working days
                                                    //     4 - 3 working days
                                                    //     5 - 5 working days
                                                    //Delivers from Partner to customer
                DeliveryType = ParcelDeliveryType.OnlyDelivery
            };
            _parcelContainer.Add(_homeDelivery);
            #endregion

            #region International home delivery - FanCourier
            //ONLY WITH CONTRACT, Read the documentation!
            Parcel _internationalHomeDelivery = new Parcel()
            {
                // required field, it decides the service type
                ServiceType = ParcelServiceType.HomeDeliver, //Home delivery to the customer

                // Parcel creation status, we only handle Create
                ParcelCreationStatus = ParcelCreationStatus.Create,

                // Logistics barcode(with the unique prefix). Max 25 chars length
                // It has to be unique and contains only ean128 format characters
                BarCode = $"{_prefix}{_datum}HDFC",    //Unique generated barcode, FanCourier will replace it

                // Accounting barcode, the partner's identifier code for the parcel, it will be shown on the accounting and searchable in the tracking
                // Visible on the label
                // Required field
                AutorizationCode = "AUTH123456",

                #region Parcel price data
                // Collect on delivery price
                PriceAtDelivery = 10.55M,
                // Collect on delivery currency
                PriceAtDeliveryCurrency = "RON",   //Have to use this currency code
                // Parcel value, used for compensation
                PackagePrice = 10.55M,
                // Parcel value currency
                PackagePriceCurrency = "RON",   //Have to use this currency code
                #endregion

                #region Customer data

                // Customer name
                CustomerName = "Atvevo Jakab",
                // Customer phone number for SMS notification. Have to use this format (Valid hungarian or romanian phone number Country prefix(+36/0036/06 or +40/0040/07) and only numbers)
                CustomerPhone = "+40712345678",
                // Customer email address
                CustomerEmail = "ugyfel@gmail.com",

                #region Customer address data

                // Customer country code. 
                CustomerCountryCode = "RO",

                //Customer postal code
                CustomerPostalCode = "050552",
                // Customer city or settlement
                CustomerCity = "Bucuresti",
                // Customer street
                CustomerAddress = "Str. Costache Negri",
                // Customer streetnumber and other (floor and door number)
                CustomerStreetNumber = "1-5",

                #endregion

                #endregion

                #region Parcel size data             
                // Parcel weight (in kilograms) (Optional)
                PackageWeight = 5,
                // Parcel Size X dimension (in centimeters) (Optional)
                PackageSizeX = 20,
                // Parcel Size Y dimension (in centimeters) (Optional)
                PackageSizeY = 31,
                // Parcel Size Z dimension (in centimeters) (Optional)
                PackageSizeZ = 10,
                // Parcel Volume (m3) (Optional)
                PackageVolume = 0.006000m,
                #endregion

                #region csomag adatok

                // Package count delivered together to the same customer
                ParcelCount = 1,            // CAUTION! The system will generate the given number of package barcode and labels (in format: Barcode, Barcode-2, Barcode-3)
                                            // The generated barcodes will be in the respone               

                #endregion

                //Transit time type                
                TransitTime = 2,  //Default 1 workday, but depends on international couriers               

                //Delivers from Partner to customer
                DeliveryType = ParcelDeliveryType.OnlyDelivery,

                //Adding International Courier information in JSON format
                SupplimentJSONData = ToJSON(new PackageSupplimentData()
                {
                    InternationalData = new InternationalData
                    {
                        DeliveryPartner = "FANCOURIER",
                        FanCourierData = new FanCourierData
                        {
                            LabelSize = LabelSize.A6,
                            IsDocument = false
                        }
                    }
                })
            };
            _parcelContainer.Add(_internationalHomeDelivery);
            #endregion

            #region Return of Document
            //Create Return of document Parcels example
            //For example, copy the original Normal Parcel
            Parcel _returnOfDocument = _normal.Clone();

            // Logistics barcode(with the unique prefix). Max 25 chars length
            // It has to be unique and contains only ean128 format characters            
            _returnOfDocument.BarCode = $"{_prefix}{_datum}Rod{ParcelServiceType.Normal}";  //"Rod" is an example string

            //Return Of Document Checked
            _returnOfDocument.ReturnOfDocument = true;

            //Destination PPP shop code (where the customer takes over the parcel). The ReturnOfDocument service is available only in particular shops.
            _returnOfDocument.DestinationLocationId = "0000101999";

            //Add to ParcelContainer list this initialized parcel
            _parcelContainer.Add(_returnOfDocument);

            //In the response there will be a generated Return package with the original Barcode + "R" suffix. The label for the Return package has to be printed as well!

            #endregion

            //Set up the request head
            RegisterParcelContainerRequest _registerParcelContainerRequest = new RegisterParcelContainerRequest()
            {
                //Test partner code, customer service gives it to partners
                PartnerCode = "0000001000",                 //Partner code, ASK FOR VALUE FROM THE pudointerface@lapker.hu!
                ParcelContainer = _parcelContainer,         //parcel list
                Supplier = Supplier.Partner,                //Obsoleted field, have to fill with Partner
                Token = "testtoken1",                       //required token field, ASK FOR VALUE FROM THE pudointerface@lapker.hu!
                                                            //ArriveDate = new DateTime(2017,1,1,18,0,0)  //Estimated time of handover, informational, optional
                //Only label print
                OnlyLabelPrinting = onlyLabelPrinting,
                FinalizeLabelPrinting = false
            };
            #endregion

            try
            {
                #region Send the request to the webservice

                //Barcode list for successfully registrated parcels
                List<BarcodeData> _barcodes = new List<BarcodeData>();

                //Connecting to the parcel registration service
                using (PartnerPudoClient _ppsClient = new PartnerPudoClient())
                {
                    // Sending the request to the logistic system
                    RegisterParcelContainerResponse _registerParcelContainerResponse = _ppsClient.RegisterParcelContainer(_registerParcelContainerRequest);

                    if (_registerParcelContainerResponse == null || _registerParcelContainerResponse.ParcelResults == null)
                    {
                        Console.WriteLine("Empty Response!");
                        Console.ReadKey();
                        return;
                    }
                    //Handling the response
                    Console.WriteLine($"Head result: {_registerParcelContainerResponse.ErrorCode}");

                    #region Handle parcel registration response                

                    foreach (ParcelResult result in _registerParcelContainerResponse.ParcelResults)
                    {
                        //Show the results
                        Console.WriteLine($"Original Barcode : {result.OriginalBarCode}");
                        Console.WriteLine($"New Barcode : {result.NewBarCode}");
                        Console.WriteLine($"ErrodCode : {result.ErrorCode}");
                        Console.WriteLine($"ShipmentID : {result.ShipmentID}");
                        if (!string.IsNullOrWhiteSpace(result.ErrorMessageInternational))
                        {
                            Console.WriteLine($"ErrorMessageInternational : {result.ErrorMessageInternational}");
                        }
                        Console.WriteLine();

                        //If the parcel has been registrated susccessfully, adding to the list
                        if (result.ErrorCode == "PSR_OK" || (onlyLabelPrinting && result.ErrorCode == "PSR_OK_PACKAGE_LABEL_PRINTING"))
                        {
                            _barcodes.Add(new BarcodeData()
                            {
                                //We collect the new barcodes from the logistic system (it can be differenet from the original Barcode)
                                Barcode = result.NewBarCode,
                                Type = BarcodeType.BT_PackageBarcode
                            });
                        }
                    }
                    #endregion
                }
                #region Label and other document generation

                if (_barcodes.Any())
                {
                    //Specify the document settings
                    List<DocumentSetting> _documentSettings = new List<DocumentSetting>();
                    _documentSettings.Add(new DocumentSetting()
                    {
                        Format = DocumentFormat.DF_PDF,
                        IsPositioned = false,//Prepared for printing on normal paper, if true then prepares for Etikett labels
                        Position = LabelDocumentPosition.P_0, //Starting position of labels on page
                        Size = LabelDocumentSize.DS_2x2, //A4 page dividing for labels
                        Type = DocumentType.DT_All //Getting all document types: Labels, recipient report and delivery notes
                    });

                    // Setting the request
                    MassDocumentRequest _massDocumentRequest = new MassDocumentRequest();
                    _massDocumentRequest.Barcodes = _barcodes;
                    _massDocumentRequest.DocumentSettings = _documentSettings;

                    //Connecting to the document generation service
                    using (DocumentClient _documentClient = new DocumentClient())
                    {
                        //Getting back the documents
                        MassDocumentResponse _massDocumentResponse = _documentClient.GetDocument(_massDocumentRequest);

                        #region Document response handling
                        switch (_massDocumentResponse.Result)
                        {
                            //If the Result is RES_OK, then the document generation was successfully and we have got back printable documents
                            case DocumentResults.RES_OK:
                                {
                                    //Write out the results
                                    foreach (DocumentGenerationResult _documentGenerationResult in _massDocumentResponse.DocumentGenerationResults)
                                    {
                                        Console.WriteLine(_documentGenerationResult.DocumentName);
                                        Console.WriteLine(_documentGenerationResult.Result);
                                        if (!String.IsNullOrWhiteSpace(_documentGenerationResult.ResultMessage))
                                        {
                                            Console.WriteLine(_documentGenerationResult.ResultMessage);
                                        }
                                        Console.WriteLine();
                                    }

                                    //There could be more documents with the same name, save them with different filenames to avoid override
                                    int _index = 1;
                                    //Save the results to files
                                    foreach (DocumentData _document in _massDocumentResponse.Documents)
                                    {
                                        using (FileStream savefile = new FileStream($"{_document.DocumentName}{_datum}{_index++}.pdf", FileMode.OpenOrCreate))
                                        {
                                            savefile.Write(_document.Document, 0, _document.Document.Count());
                                            savefile.Flush();
                                        }
                                    }
                                    break;
                                }
                            case DocumentResults.RES_GENERATE_ERROR:
                                {
                                    Console.Write("Error occured during generation");
                                    break;
                                }
                            case DocumentResults.RES_DATA_MISSING:
                                {
                                    Console.Write("Data is missing");
                                    break;
                                }
                            default:
                                {
                                    Console.Write(_massDocumentResponse.Result);
                                    break;
                                }
                        }
                        #endregion
                    }
                }
                #endregion

                #endregion

                #region Finalize label printing

                //At the end, Finalize the parcel data in the logistics system
                if (onlyLabelPrinting)
                {
                    //Set up the request head
                    RegisterParcelContainerRequest _registerParcelContainerRequestFinalize = new RegisterParcelContainerRequest()
                    {
                        //Test partner code, customer service gives it to partners
                        PartnerCode = "0000001000",                 //Partner code, ASK FOR VALUE FROM THE pudointerface@lapker.hu!

                        //Finalize the selected parcels.
                        ParcelContainer = _barcodes.Select(b => new Parcel { BarCode = b.Barcode }).ToList(),
                        //ParcelContainer = new List<Parcel> { new Parcel { BarCode = _normal.BarCode }, new Parcel { BarCode = _homeDelivery.BarCode } },        

                        Supplier = Supplier.Partner,                //Obsoleted field, have to fill with Partner
                        Token = "testtoken1",                       //required token field, ASK FOR VALUE FROM THE pudointerface@lapker.hu!                                                     
                        //ArriveDate = new DateTime(2017,1,1,18,0,0)  //Estimated time of handover, informational, optional

                        OnlyLabelPrinting = false,
                        FinalizeLabelPrinting = onlyLabelPrinting
                    };

                    //Connecting to the parcel registration service
                    using (PartnerPudoClient _ppsClientFinalize = new PartnerPudoClient())
                    {
                        // Sending the request to the logistic system
                        RegisterParcelContainerResponse _registerParcelContainerFinalizeResponse = _ppsClientFinalize.RegisterParcelContainer(_registerParcelContainerRequestFinalize);

                        #region Handle parcel finalize registration response
                        if (_registerParcelContainerFinalizeResponse == null || _registerParcelContainerFinalizeResponse.ParcelResults == null)
                        {
                            Console.WriteLine("Empty Response!");
                            Console.ReadKey();
                            return;
                        }
                        //Handling the response
                        Console.WriteLine($"Head result: {_registerParcelContainerFinalizeResponse.ErrorCode}");

                        foreach (ParcelResult result in _registerParcelContainerFinalizeResponse.ParcelResults)
                        {
                            //Show the results
                            Console.WriteLine($"Original Barcode : {result.OriginalBarCode}");
                            Console.WriteLine($"New Barcode : {result.NewBarCode}");
                            Console.WriteLine($"ErrodCode : {result.ErrorCode}");
                            Console.WriteLine($"ShipmentID : {result.ShipmentID}");
                            if (!string.IsNullOrWhiteSpace(result.ErrorMessageInternational))
                            {
                                Console.WriteLine($"ErrorMessageInternational : {result.ErrorMessageInternational}");
                            }
                            Console.WriteLine();
                        }
                        #endregion
                    }
                }
                #endregion
            }
            catch (Exception ex)
            {
                Console.WriteLine($"Error occured! :{ex.Message}");
            }


            Console.ReadKey();
        }


        /// <summary>
        /// Converts the object to JSON string
        /// </summary>
        /// <param name="obj"></param>
        /// <returns></returns>
        static String ToJSON(object obj)
        {
            //Create SupplimentJSONData for International home delivery
            DataContractJsonSerializer serializedData = new DataContractJsonSerializer(typeof(PackageSupplimentData));
            using (MemoryStream memoryStream = new MemoryStream())
            {
                serializedData.WriteObject(memoryStream, obj);

                memoryStream.Position = 0;
                using (StreamReader streamAtSupplimentJSONData = new StreamReader(memoryStream))
                {
                    return streamAtSupplimentJSONData.ReadToEnd();
                }
            }
        }
    }
}
