﻿using System;
using System.IO;
using System.Net;
using System.Net.Http;
using System.Web.Http;
using Lapker.Pudo.InterfaceModel.InterfaceModel.UnifiedParcelTrackingInfo;
using Sprinter.Pudo.UnifiedParcelTrackingEmulator;

namespace UnifiedParcelTrackingEmulator.Controllers
{
    /// <summary>
    /// Receives tracking information
    /// </summary>
    public class TrackingController : ApiController
    {
        /// <summary>
        /// Allow to post TrackingInformation in a UnifiedParcelTrackingInfo model
        /// </summary>
        /// <param name="request">UnifiedParcelTrackingInfo model, contains tracking history list</param>
        /// <returns>HttpResponse 200 OK and "success" message</returns>
        public HttpResponseMessage Post([FromBody]UnifiedParcelTrackingInfo request)
        {
            try
            {
                #region Check request

                if (request == null)
                {
                    return Request.CreateErrorResponse(HttpStatusCode.BadRequest, "The request is null!");
                }

                if (request.TrackingInfoList == null || request.TrackingInfoList.Count == 0)
                {
                    return Request.CreateErrorResponse(HttpStatusCode.BadRequest, "The TrackingInfoList is empty!");
                }

                //Basic check if we got valid data
                if (!ModelState.IsValid)
                {
                    return Request.CreateErrorResponse(HttpStatusCode.BadRequest, ModelState);
                }
                #endregion

                #region Process data

                //TODO Process the tracking data
                //For example: 
                Directory.CreateDirectory(@"c:\temp\UnifiedParcelTrackingInfo");
                File.WriteAllText($@"c:\temp\UnifiedParcelTrackingInfo\TrackingDataPosted_{DateTime.Now.ToString("yyyy_MM_dd_HH_mm_ss_fff")}.json", SerializerHelper.JsonFromObject(request));

                #endregion

                #region Return result

                //Return the success result
                return Request.CreateResponse(HttpStatusCode.OK, "success");

                #endregion
            }
            catch (Exception ex)
            {
                //Return the error
                return Request.CreateResponse(HttpStatusCode.InternalServerError, $"Error occured! ErrorMessage: {ex.Message}, Request was: {SerializerHelper.GetStringFromObject(request)}");
            }
        }
    }
}
