﻿using Newtonsoft.Json;
using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Runtime.Serialization;
using System.Text;
using System.Threading.Tasks;

namespace Sprinter.Pudo.UnifiedParcelTrackingEmulator
{
    /// <summary>
    /// JSON serializationHelper
    /// </summary>
    public static class SerializerHelper
    {
        /// <summary>
        /// Returns a JSON string from an object
        /// </summary>
        /// <typeparam name="T"></typeparam>
        /// <param name="jsonObject"></param>
        /// <returns></returns>
        public static string JsonFromObject<T>(T jsonObject)
        {
            try
            {
                JsonSerializer _serializer = new JsonSerializer();

                StringBuilder builder = new StringBuilder();
                using (StringWriter stringWriter = new StringWriter(builder))
                {
                    using (JsonTextWriter writer = new JsonTextWriter(stringWriter))
                    {
                        _serializer.Serialize(writer, jsonObject);
                    }
                }

                return builder.ToString();
            }
            catch (Exception)
            {
                throw;
            }
        }

        /// <summary>
        /// Returns a serialized string from object
        /// </summary>
        /// <param name="item">Object</param>
        /// <returns>string</returns>
        public static string GetStringFromObject<T>(T item)
        {
            StringBuilder _sb = new StringBuilder();

            if (item != null)
            {
                try
                {
                    using (MemoryStream _ms = new MemoryStream())
                    {
                        _ms.Position = 0;

                        DataContractSerializer _dataContractSerializer = new DataContractSerializer(item.GetType());

                        _dataContractSerializer.WriteObject(_ms, item);

                        _ms.Position = 0;

                        using (StreamReader _sr = new StreamReader(_ms))
                        {
                            _sb.Append(_sr.ReadToEnd());
                        }
                    }
                }
                catch (Exception ex)
                {
                    _sb.Append(ex.Message);
                    _sb.Append(ex.StackTrace);
                }
            }
            else
            {
                _sb.Append("null");
            }

            return _sb.ToString();
        }
    }
}
