﻿using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using System.Runtime.Serialization;

namespace Lapker.Pudo.InterfaceModel.InterfaceModel.UnifiedParcelTrackingInfo
{
    /// <summary>
    /// Tracking information
    /// </summary>
    [DataContract(Namespace = "http://Lapker.Pudo.InterfaceModel.InterfaceModel.UnifiedParcelTrackingInfo")]
    public class TrackingInfo
    {
        /// <summary>     
        /// Tracking ID. It's a unique identifier for the tracking. You can validate if we have sent it before.
        /// </summary>
        [DataMember]
        [Required]
        public int TrackingID { get; set; }

        /// <summary>
        /// Parcel barcode, the logistic identifier of the parcel
        /// </summary>
        [DataMember]
        [Required]
        public string ParcelBarcode { get; set; }

        /// <summary>
        /// For home delivery parcels this is the identifier for the parcels delivered at the same address
        /// </summary>
        [DataMember]
        public string HomeDeliveryNoteNumber { get; set; }

        /// <summary>
        /// Shipment ID connected to the parcel, which is generated by the system.
        /// In case of PPP service, 1 ID is generated per ServiceType.
        /// In case of HD service each Parcel has a separated ID.
        /// </summary>
        [DataMember]
        public string ShipmentID { get; set; }

        /// <summary>
        /// Original barcode, which was sent at the registration
        /// </summary>
        [DataMember]
        public string OriginalBarCode { get; set; }

        /// <summary>
        /// Order code, which is the partner’s own parcel code or invoice number (if an invoice can be found in the box).
        /// </summary>
        [DataMember]
        public string AutorizationCode { get; set; }

        /// <summary>
        /// Invoice number placed in the parcel, should be the same as AutorizationCode
        /// </summary>
        [DataMember]
        public string InvoiceNumber { get; set; }

        /// <summary>
        /// Status change creation time
        /// </summary>
        [DataMember]
        [Required]
        public DateTime EventCreatedTime { get; set; }

        /// <summary>
        /// Delivery mode: PICKPACKPOINT or HOMEDELIVERY
        /// </summary>
        [DataMember]
        [Required]
        public string DeliveryMode { get; set; }

        /// <summary>
        /// Partner tracking main status name
        /// </summary>
        [DataMember]
        [Required]
        public string PartnerMainStatusName { get; set; }

        /// <summary>
        /// Partner tracking main status description list by languages
        /// </summary>
        [DataMember]
        [Required]
        public List<Translation> PartnerMainStatusDescriptionList { get; set; }

        /// <summary>
        /// Partner tracking substatus name
        /// </summary>
        [DataMember]
        public string PartnerSubStatusName { get; set; }

        /// <summary>
        /// Partner tracking substatus description list by languages
        /// </summary>
        [DataMember]
        public List<Translation> PartnerSubStatusDescriptionList { get; set; }

        /// <summary>
        /// Customer tracking status name
        /// </summary>
        [DataMember]
        public string CustomerStatusName { get; set; }

        // TODO CustomerStatusResourceKeyForDescription+ResourceKeyForAdditionalDescription
        /// <summary>
        /// Customer tracking status description list by languages
        /// </summary>
        [DataMember]
        public List<Translation> CustomerStatusDescriptionList { get; set; }

        /// <summary>
        /// Delivery refuse reason name
        /// </summary>
        [DataMember]
        public string RefuseReasonName { get; set; }

        /// <summary>
        /// Delivery refuse reason description list by languages
        /// </summary>
        [DataMember]
        public List<Translation> RefuseReasonDescriptionList { get; set; }

        /// <summary>
        /// Customer name
        /// </summary>
        [DataMember]
        public string CustomerName { get; set; }

        /// <summary>
        /// Expected arrival of parcel to customer from time
        /// </summary>
        [DataMember]
        public DateTime? ExpectedArrivalFrom { get; set; }

        /// <summary>
        /// Expected arrival of parcel to customer to time
        /// </summary>
        [DataMember]
        public DateTime? ExpectedArrivalTo { get; set; }

        /// <summary>
        /// Destination PPP code
        /// </summary>
        [DataMember]
        public string DestinationLocationCode { get; set; }

        /// <summary>
        /// Destination PPP name
        /// </summary>
        [DataMember]
        public string DestinationLocationName { get; set; }

        /// <summary>
        /// Destination PPP address
        /// </summary>
        [DataMember]
        public string DestinationLocationAddress { get; set; }

        /// <summary>
        /// Delivery partner name (at International delivery for example: FanCourier)
        /// </summary>
        [DataMember]
        public string InternationalDeliveryPartnerName { get; set; }

        /// <summary>
        /// Measured weight in kilograms
        /// </summary>
        [DataMember]
        public decimal? MeasuredWeight { get; set; }
    }
}
