<?php


//Tracking object
class UnifiedParcelTrackingInfo{

    /**
    * Partner identifier
    * @var string
    * @required
    */
    public $PartnerCode; 
  
    /**
    * Tracking data list
    * @var \TrackingInfo[]
    * @required
    */
    public $TrackingInfoList;    
}

//Translations in different languages
class Translation{
  
	/**
 	* Language name
 	* @var string
	*/
	public $LanguageName;

	/**
 	* Translated text
 	* @var string
	*/
	public $TranslatedText;
}

   
//Contains Parcel information and status history
class TrackingInfo{

	/**
 	* Tracking ID. It's a unique identifier for the tracking. You can validate if we have sent it before.        
 	* @var int
	* @required
	*/
	public $TrackingID;

	/**
 	* Parcel barcode, the logistic identifier of the parcel        
 	* @var string
	* @required
	*/
	public $ParcelBarcode;

	/**
 	* For home delivery parcels this is the identifier for the parcels delivered at the same address        
 	* @var string|null
	*/
	public $HomeDeliveryNoteNumber;

	/**
 	* Shipment ID connected to the parcel, which is generated by the system.
    * In case of PPP service, 1 ID is generated per ServiceType.
    * In case of HD service each Parcel has a separated ID.        
 	* @var string|null
	*/
	public $ShipmentID;

	/**
 	* Original barcode, which was sent at the registration        
 	* @var string|null
	*/
	public $OriginalBarCode;

	/**
 	* Order code, which is the partners own parcel code or invoice number (if an invoice can be found in the box).        
 	* @var string|null
	*/
	public $AutorizationCode;

	/**
 	* Invoice number placed in the parcel, should be the same as AutorizationCode        
 	* @var string|null
	*/
	public $InvoiceNumber;

	/**
 	* Status change creation time        
 	* @var string
	* @required
	*/
	public $EventCreatedTime;

	/**
 	* Delivery mode: PICKPACKPOINT or HOMEDELIVERY        
 	* @var string
	* @required
	*/
	public $DeliveryMode;

	/**
 	* Partner tracking main status name        
 	* @var string
	* @required
	*/
	public $PartnerMainStatusName;

	/**
 	* Partner tracking main status description list by languages        
 	* @var \Translation[]
	* @required
	*/
	public $PartnerMainStatusDescriptionList;

	/**
 	* Partner tracking substatus name        
 	* @var string|null
	*/
	public $PartnerSubStatusName;

	/**
 	* Partner tracking substatus description list by languages        
 	* @var \Translation[]|null
	*/
	public $PartnerSubStatusDescriptionList;

	/**
 	* Customer tracking status name        
 	* @var string
	*/
	public $CustomerStatusName;

	/**
 	* Customer tracking status description list by languages        
 	* @var \Translation[]
	*/
	public $CustomerStatusDescriptionList;

	/**
 	* Delivery refuse reason name        
 	* @var string|null
	*/
	public $RefuseReasonName;

	/**
 	* Delivery refuse reason description list by languages        
 	* @var \Translation[]|null
	*/
	public $RefuseReasonDescriptionList;

	/**
 	* Customer name        
 	* @var string|null
	*/
	public $CustomerName;

	/**
 	* Expected arrival of parcel to customer from time        
 	* @var string|null
	*/
	public $ExpectedArrivalFrom;

	/**
 	* Expected arrival of parcel to customer to time        
 	* @var string|null
	*/
	public $ExpectedArrivalTo;

	/**
 	* Destination PPP code        
 	* @var string|null
	*/
	public $DestinationLocationCode;

	/**
 	* Destination PPP name        
 	* @var string|null
	*/
	public $DestinationLocationName;

	/**
 	* Destination PPP address        
 	* @var string|null
	*/
	public $DestinationLocationAddress;

	/**
 	* Delivery partner name (at International delivery for example: FanCourier)        
 	* @var string|null
	*/
	public $InternationalDeliveryPartnerName;

	/**
 	* Measured weight in kilograms        
 	* @var float|null
	*/
	public $MeasuredWeight;

}

?>