﻿<?php

$request = "";
try{

// include other php files
include("Model.php"); //Classes for Json model validation
include("JsonMapper/JsonMapper.php"); //Helper for Json validation
include("JsonMapper/Exception.php"); //JsonMapper exception classes

#region Validate request

//Make sure that it is a POST request.
if(strcasecmp($_SERVER['REQUEST_METHOD'], 'POST') != 0){
    http_response_code(405);//Method Not Allowed
    echo 'Request method must be POST!';
    exit;
}

//Make sure that the content type of the POST request has been set to application/json
$contentType = isset($_SERVER["CONTENT_TYPE"]) ? trim($_SERVER["CONTENT_TYPE"]) : '';

if(strcasecmp($contentType, 'application/json; charset=utf-8') != 0){
    http_response_code(415);//Unsupported Media Type
    echo "Content type must be: application/json; charset=utf-8. Request content type was: ". $contentType;
    exit;
}
#endregion

#region Validate data

//Receive the RAW post data.
$request = trim(file_get_contents("php://input"));


//Attempt to decode the incoming RAW post data from JSON.
$contentObjectFromJson = json_decode($request);

try{

    //Map and validate the Json object to the UnifiedParcelTrackingInfo class.
    //https://github.com/cweiske/jsonmapper
    $mapper = new JsonMapper();
    $mapper->bExceptionOnMissingData = true; //Validate required fields!
    $validatedContentObject = $mapper->map($contentObjectFromJson, new UnifiedParcelTrackingInfo());        

	if(count($validatedContentObject->TrackingInfoList) == 0)
	{
		http_response_code(400);//Bad Request
		echo "The TrackingInfoList is empty! ".PHP_EOL."Request was: ".$request;
		exit;
	}
}
catch(exception $e){
    http_response_code(400);//Bad Request
    echo "The request is invalid. ".PHP_EOL."ErrorMessage: ".$e.PHP_EOL."Request was: ".$request;
    exit;
}

#endregion

#region Process data
//After this $validatedContentObject is an instance of UnifiedParcelTrackingInfo and contains the posted data from json

//TODO Process the tracking data...

//For example write to file
$date = date('c');

//Store the Json request
file_put_contents("TrackingDataPosted_".date('YmdHis').".json", serialize($request).PHP_EOL, FILE_APPEND);

//Store the Tracking item objects
foreach($validatedContentObject->TrackingInfoList as $trackingItem){
    file_put_contents("TrackingObjectList_".date('Ymd').".txt", serialize($trackingItem).PHP_EOL, FILE_APPEND);
}

#endregion

//At the end return success with HTTP status 200
echo "success";

}
catch(exception $e){
    http_response_code(500);//Internal Server Error

    echo "Error occured! ".PHP_EOL."ErrorMessage: ".$e.PHP_EOL."Request was: ".$request;
    exit;
}



?>